/* $Id: LoginController.groovy 28088 2008-04-02 22:25:13Z caulfield14 $ */

import com.atlassian.crowd.integration.service.soap.client.SecurityServerClient
import com.atlassian.crowd.integration.http.HttpAuthenticator
import com.atlassian.crowd.integration.exception.InactiveAccountException
import com.atlassian.crowd.integration.exception.InvalidAuthenticationException
import com.atlassian.crowd.integration.exception.InvalidAuthorizationTokenException
import com.atlassian.crowd.integration.soap.SOAPPrincipal
import java.rmi.RemoteException
import org.codehaus.groovy.grails.commons.ConfigurationHolder


class LoginController {
    static authenticate= false
    static authorize= []

    HttpAuthenticator httpAuthenticator
    SecurityServerClient securityServerClient

    def index = {
        def command = new LoginCommand()
        if (session.authenticate) {
            flash.message = "authorize.user.authenticate"
            session.authenticate = null
        }
        render(view: "login", model: [command:command])
    }

    def login = {LoginCommand command ->
        // Check for errors and send back if required
        if (command.hasErrors()) {
            command.password= null
            return [command:command]
        }

        // Process login, catch and deal with exceptions
        // If user has been authenticated via Crowd/SSO, the SecurityFilter will set up the session
        // structure at the next request that requires authentication.
        try {
            httpAuthenticator.authenticate(request, response, command.username, command.password)
        }
        catch (InvalidAuthenticationException e) {
            //
            command.errors.reject("crowdAuth.invalidAuthentication")
            command.password= null
            return [command:command]
        }
        catch (InvalidAuthorizationTokenException e) {
            command.errors.reject("crowdAuth.invalidAuthorizationToken")
            command.password= null
            return [command:command]
        }
        catch (RemoteException e) {
            command.errors.reject("crowdAuth.remote")
            command.password= null
            return [command:command]
        }
        catch (InactiveAccountException e) {
            command.errors.reject("crowdAuth.inactiveAccount")
            command.password= null
            return [command:command]
        }

        // Send them on their way
        if (session.originalRequestParams) {
            redirect(controller: session.originalRequestParams.controller,
                    action: session.originalRequestParams.action,
                    params: session.originalRequestParams)
            session.originalRequestParams= null
            return;
        }
        else {
            redirect(uri:'/')
        }
    }
}

class LoginCommand {
    String username
    String password

    static constraints = {
        username(nullable: false, blank: false)
        password(nullable: false, blank: false)
    }
}